package org.opengroup.osdu.register.api.test;

import javax.inject.Inject;
import javax.inject.Provider;
import javax.validation.ValidationException;
import javax.validation.constraints.NotBlank;

import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.register.api.dto.ChallengeResponse;
import org.opengroup.osdu.register.provider.interfaces.verifier.GsaTokenVerifier;
import org.opengroup.osdu.register.utils.AppServiceConfig;
import org.opengroup.osdu.register.utils.HashingUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.annotation.RequestScope;

//used as both documentation and by integration test to validate challenge response logic
@RestController
@RequestMapping("/test")
@RequestScope
@Validated
public class GsaSubscriberListenerApi {

  @Autowired
  protected AppServiceConfig serviceConfig;
  @Autowired
  private GsaTokenVerifier gsaTokenVerifier;
  @Inject
  private Provider<DpsHeaders> headersProvider;
  @Autowired
  protected JaxRsDpsLog logger;

  @GetMapping("/gsa-challenge/{count}")
  public ChallengeResponse testGsa(@RequestParam("crc") @NotBlank String crc) {
    DpsHeaders headers = headersProvider.get();
    if (!gsaTokenVerifier.verify(headers.getAuthorization())) {
      throw new ValidationException("Authorization signature validation Failed");
    }
    logger.debug("Token verified and sending response");
    return new ChallengeResponse(HashingUtil.hashString(crc, this.serviceConfig.getSubscriberPrivateKeyId()));
  }

  @PostMapping("/gsa-challenge/{count}")
  public void testPushGsa(@RequestBody Object o) {
    DpsHeaders headers = headersProvider.get();
    if (!gsaTokenVerifier.verify(headers.getAuthorization())) {
      throw new ValidationException("Authorization signature validation Failed");
    }
    logger.debug("Sending acknowledgement from gsa endpoint");
  }

}
