/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.ddms.services;

import org.apache.http.HttpStatus;
import org.opengroup.osdu.register.ddms.model.Ddms;
import org.opengroup.osdu.register.ddms.model.RegisteredInterface;
import org.opengroup.osdu.register.provider.interfaces.ddms.IDdmsRepository;
import org.opengroup.osdu.core.common.model.http.AppException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.net.URI;

@Service
public class ConsumptionService {

    @Autowired
    private IDdmsRepository dmsRepository;

    public URI getSingleEntityRetrivalUri(String id, String type, String localid) throws Exception {
        Ddms ddms = this.dmsRepository.get(id);
        if (ddms == null) {
            throwNotFoundEndpoint(id, type);
        }

        RegisteredInterface ri = ddms.getInterfaceByType(type);
        if (ri == null) {
            return throwNotFoundEndpoint(id, type);
        }

        URI out = ri.retrieveSingleEntityURI(localid);
        if (out == null) {
            throwNotFoundEndpoint(id, type);
        }

        return out;
    }

    private URI throwNotFoundEndpoint(String id, String type) {
        throw new AppException(HttpStatus.SC_NOT_FOUND, "Not found", String.format("Either the DDMS with the given id or the retrieval endpoint on DDMS interface was not found. ID: %s Type: %s", id, type));
    }
}
