/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.subscriber.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import org.opengroup.osdu.register.utils.Constants;
import org.opengroup.osdu.register.subscriber.model.validators.ValidSecret;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;


@Data
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.PROPERTY, property = "secretType")
@JsonSubTypes({
        @JsonSubTypes.Type(value = HmacSecret.class, name = Constants.HMACSecret),
        @JsonSubTypes.Type(value = GsaSecret.class, name = Constants.GSASecret) }
)
@SuperBuilder
@ValidSecret
@NoArgsConstructor
public abstract class Secret {
    @JsonIgnore
    private String secretType = "";

    protected Secret(String secretType) {
        this.secretType = secretType;
    }
}
