/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.utils;

import org.glassfish.jersey.uri.UriTemplate;

import javax.ws.rs.core.UriBuilder;
import java.net.URI;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class UriResolver {

    public URI getUri(String baseUrl, String relativeUrl, String... params) {
        String template = this.appendSegmentToPath(baseUrl, relativeUrl);
        UriTemplate uriTemplate = new UriTemplate(template);

        List<String> templateVariables = uriTemplate.getTemplateVariables();
        if (templateVariables == null) {
            return UriBuilder.fromUri(baseUrl).path(relativeUrl).build().normalize();
        }

        if (templateVariables.size() != params.length) {
            return null;
        }

        Map<String, String> parameters = new HashMap<>();
        for (int i = 0; i < templateVariables.size(); i++) {
            parameters.put(templateVariables.get(i), params[i]);
        }

        UriBuilder builder = UriBuilder.fromPath(template);
        return builder.buildFromMap(parameters).normalize();
    }

    private String appendSegmentToPath(String path, String segment) {
        if (path == null || path.isEmpty()) {
            return "/" + segment;
        }

        if (path.charAt(path.length() - 1) == '/') {
            return path + segment;
        }

        return path + "/" + segment;
    }
}