/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.ddms.model.validators;

import org.opengroup.osdu.register.ddms.model.Ddms;
import org.opengroup.osdu.register.ddms.model.RegisteredInterface;
import org.opengroup.osdu.register.utils.OpenApiFileUtils;
import org.junit.Test;

import javax.validation.ConstraintValidatorContext;
import java.util.ArrayList;
import java.util.List;

import static org.junit.Assert.*;
import static org.mockito.Mockito.mock;

public class RegisteredInterfacesValidatorTest {

    @Test
    public void should_passValidation_when_providing1Interface() throws Exception {
        ConstraintValidatorContext context = mock(ConstraintValidatorContext.class);
        RegisteredInterfacesValidator validator = new RegisteredInterfacesValidator();

        Ddms model = OpenApiFileUtils.getDmsWithOpenSpec("validations/openapi/invalidOpenApiVersion.json", "testType");
        List<RegisteredInterface> input = new ArrayList<>();
        input.add(model.getFirst());
        assertTrue(validator.isValid(input, context));
    }

    @Test
    public void should_failValidation_when_emptyCollection() {
        ConstraintValidatorContext context = mock(ConstraintValidatorContext.class);
        RegisteredInterfacesValidator validator = new RegisteredInterfacesValidator();

        List<RegisteredInterface> input = new ArrayList<>();
        assertFalse(validator.isValid(input, context));
    }

    @Test
    public void should_failValidation_when_duplicateTypeInCollection() throws Exception {
        ConstraintValidatorContext context = mock(ConstraintValidatorContext.class);
        RegisteredInterfacesValidator validator = new RegisteredInterfacesValidator();


        Ddms model = OpenApiFileUtils.getDmsWithOpenSpec("validations/openapi/invalidOpenApiVersion.json", "testType");
        List<RegisteredInterface> input = new ArrayList<>();
        input.add(model.getFirst());
        input.add(model.getFirst());

        assertFalse(validator.isValid(input, context));
    }

    @Test
    public void should_failValidation_when_moreThan10InCollection() throws Exception {
        ConstraintValidatorContext context = mock(ConstraintValidatorContext.class);
        RegisteredInterfacesValidator validator = new RegisteredInterfacesValidator();

        List<RegisteredInterface> input = new ArrayList<>();

        Ddms model = OpenApiFileUtils.getDmsWithOpenSpec("validations/openapi/invalidOpenApiVersion.json", "testType");
        for(int i = 0;i < 12; i++){
            model.getFirst().setEntityType(String.format("%s",i));
            input.add(model.getFirst());
        }
        assertFalse(validator.isValid(input, context));
    }
}