/*
  Copyright 2002-2021 Google LLC
  Copyright 2002-2021 EPAM Systems, Inc

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */

package org.opengroup.osdu.register.logging;

import static org.mockito.Matchers.any;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

import java.util.Collections;
import java.util.List;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.runners.MockitoJUnitRunner;
import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;

@RunWith(MockitoJUnitRunner.class)
public class AuditLoggerTest {

  @Mock
  private JaxRsDpsLog log;

  @Mock
  private DpsHeaders headers;

  @InjectMocks
  private AuditLogger sut;

  private List<String> resources;

  @Before
  public void setup() {
    when(this.headers.getUserEmail()).thenReturn("test_user@email.com");
    resources = Collections.singletonList("resources");
  }

  @Test
  public void should_writeCreateDmsSuccessEvent() {
    this.sut.createDmsSuccess(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeCreateDmsFailureEvent() {
    this.sut.createDmsFailure(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeDeleteDmsSuccessEvent() {
    this.sut.deleteDmsSuccess(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeDeleteDmsFailureEvent() {
    this.sut.deleteDmsFailure(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeCreateSubscriptionSuccessEvent() {
    this.sut.createSubscriptionSuccess(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeCreateSubscriptionFailureEvent() {
    this.sut.createSubscriptionFailure(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeDeleteSubscriptionSuccessEvent() {
    this.sut.deleteSubscriptionSuccess(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeDeleteSubscriptionFailureEvent() {
    this.sut.deleteSubscriptionFailure(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeUpdateSubscriptionSecretSuccessEvent() {
    this.sut.updateSubscriptionSecretSuccess(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeUpdateSubscriptionSecretFailureEvent() {
    this.sut.updateSubscriptionSecretFailure(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeReadActionSuccessEvent() {
    this.sut.readActionSuccess(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeReadActionFailureEvent() {
    this.sut.readActionFailure(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeReadMultipleActionsSuccessEvent() {
    this.sut.readMultipleActionsSuccess(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeReadMultipleActionsFailureEvent() {
    this.sut.readMultipleActionsFailure(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeCreateActionSuccessEvent() {
    this.sut.createActionSuccess(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeCreateActionFailureEvent() {
    this.sut.createActionFailure(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeDeleteActionSuccessEvent() {
    this.sut.deleteActionSuccess(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeDeleteActionFailureEvent() {
    this.sut.deleteActionFailure(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeValidateActionSuccessEvent() {
    this.sut.validateActionSuccess(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeValidateActionFailureEvent() {
    this.sut.validateActionFailure(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeReadSubscriptionSuccessEvent() {
    this.sut.readSubscriptionSuccess(this.resources);

    verify(this.log, times(1)).audit(any());
  }

  @Test
  public void should_writeReadSubscriptionFailureEvent() {
    this.sut.readSubscriptionFailure(this.resources);

    verify(this.log, times(1)).audit(any());
  }
}