/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.subscriber.services;

import org.opengroup.osdu.register.logging.AuditLogger;
import org.opengroup.osdu.register.subscriber.model.HmacSecret;
import org.opengroup.osdu.register.subscriber.model.Subscription;
import org.opengroup.osdu.register.provider.interfaces.subscriber.ISubscriptionRepository;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.runners.MockitoJUnitRunner;

import static junit.framework.TestCase.assertTrue;
import static org.junit.Assert.*;
import static org.mockito.Matchers.any;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

@RunWith(MockitoJUnitRunner.class)
public class DeleteSubscriptionTest {
    @Mock
    private ISubscriptionRepository subscriptionRepository;
    @Mock
    private AuditLogger auditLogger;

    @InjectMocks
    private DeleteSubscription sut;

    @Test
    public void should_returnTrueWhenDeleteSucceeds() {
        String id = "id_1";
        HmacSecret newSecret = new HmacSecret();
        newSecret.setValue("newValue");
        Subscription subscription = new Subscription();
        subscription.setId(id);
        when(subscriptionRepository.get(id)).thenReturn(subscription);
        when(subscriptionRepository.delete(id)).thenReturn(true);
        when(subscriptionRepository.get(id)).thenReturn(subscription);

        assertTrue(sut.run(subscription.getId()));
        verify(this.auditLogger).deleteSubscriptionSuccess(any());
        verify(this.subscriptionRepository).delete(id);
    }

    @Test
    public void should_returnTrueWhenDeleteFails() {
        String id = "id_1";
        HmacSecret newSecret = new HmacSecret();
        newSecret.setValue("newValue");
        Subscription subscription = new Subscription();
        subscription.setId(id);
        when(subscriptionRepository.get(id)).thenReturn(subscription);
        when(subscriptionRepository.delete(id)).thenReturn(false);

        assertFalse(sut.run(subscription.getId()));
    }
}
