/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.action;

import com.google.common.base.Strings;
import org.opengroup.osdu.register.util.Config;
import org.opengroup.osdu.register.util.RestDescriptor;

public class CreateActionDescriptor extends RestDescriptor {
    @Override
    public String getPath() {
        return "api/register/v1/action";
    }

    @Override
    public String getHttpMethod() {
        return "POST";
    }

    @Override
    public String getValidBody() {
        String url = "";
        String pushPath = System.getProperty("REGISTER_CUSTOM_PUSH_URL", System.getenv("REGISTER_CUSTOM_PUSH_URL"));
        if( Strings.isNullOrEmpty(pushPath)) {
            url= Config.Instance().securePushUrl + "api/register/v1/test/challenge";
        }
        else
        {
            url = pushPath;
        }

        return "{\n" +
                "\t\"id\": \"" + getArg() + "\",\n" +
                "\t\"name\": \"My listener\",\n" +
                "\t\"description\": \"My test listener.\",\n" +
                "\t\"url\":\"" + url + "\",\n" +
                "\t\"img\": \"" + url + "\",\n" +
                "\t\"contactEmail\": \"" + "integrationtest@test.com" + "\",\n" +
                "\t\"filter\": {\n" +
                "\t\"entityType\": [\"*\"],\n" +
                "\t\"source\": [\"*\"],\n" +
                "\t\"version\": [\"*\"]}\n" +
                "}";
    }

}
