/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.ddms;

import com.google.gson.Gson;
import org.opengroup.osdu.register.model.Ddms;
import org.opengroup.osdu.register.util.BaseTestTemplate;
import org.opengroup.osdu.register.util.RestDescriptor;
import com.sun.jersey.api.client.ClientResponse;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

public abstract class QueryDdmsByTypeTest extends BaseTestTemplate {

    public QueryDdmsByTypeTest() {
        super(new QueryDdmsByTypeDescriptor());
    }

    @Override
    protected boolean isDataInTenant() {
        return true;
    }

    private String id = "querytest" + System.currentTimeMillis();

    @Override
    protected String getId() {
        return id;
    }

    @Override
    protected void deleteResource() throws Exception {
        new DeleteDdmsDescriptor().run(getId(), testUtils.getOpsAccessToken());
    }

    @Override
    protected void createResource() throws Exception {
        ClientResponse response = new CreateDdmsDescriptor().run(getId(), testUtils.getOpsAccessToken());
        assertEquals(error(response.getEntity(String.class)), 201, response.getStatus());
    }

    @Override
    protected int expectedOkResponseCode() {
        return 200;
    }

    @Override
    public void should_return20XResponseCode_when_makingValidHttpsRequest() throws Exception {
        createResource();
        ClientResponse response = descriptor.run("wellbore", testUtils.getOpsAccessToken());
        assertEquals(error(""), expectedOkResponseCode(), response.getStatus());
        validate20XResponse(response, descriptor);

        response = descriptor.run("wellb", testUtils.getOpsAccessToken());
        assertEquals(error(""), expectedOkResponseCode(), response.getStatus());
        String body = response.getEntity(String.class);
        Ddms[] ddmsArr = new Gson().fromJson(body, Ddms[].class);
        List<Ddms> allDms = Arrays.asList(ddmsArr);
        assertEquals(0, allDms.size());

        deleteResource();
    }

    @Override
    protected void validate20XResponse(ClientResponse response, RestDescriptor descriptor) {
        String body = response.getEntity(String.class);
        Ddms[] ddmsArr = new Gson().fromJson(body, Ddms[].class);
        List<Ddms> allDms = Arrays.asList(ddmsArr);
        assertTrue(allDms.size() >= 1);

        List<Ddms> ddms = allDms.stream().filter(f -> f.id.equalsIgnoreCase(getId())).collect(Collectors.toList());
        assertEquals(1, ddms.size());
        assertEquals("My test ddms.", ddms.get(0).description);
        assertTrue(ddms.get(0).contactEmail, ddms.get(0).contactEmail.equals("test@test.com"));
        assertEquals("logDDMS", ddms.get(0).name);
        assertEquals(1, ddms.get(0).interfaces.size());
        assertEquals("wellbore", ddms.get(0).interfaces.iterator().next().entityType);
    }
}
