/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.util;

import com.sun.jersey.api.client.ClientResponse;
import org.junit.Ignore;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

public abstract class ConsumptionApiTemplate extends BaseTestTemplate {

    public ConsumptionApiTemplate(RestDescriptor getDescriptor, RestDescriptor deleteDescriptor, RestDescriptor createDescriptor) {
        super(getDescriptor);
        this.createDescriptor = createDescriptor;
        this.deleteDescriptor = deleteDescriptor;
    }

    private RestDescriptor createDescriptor;
    private RestDescriptor deleteDescriptor;
    private String id = "gettest" + System.currentTimeMillis();

    @Override
    protected String getId() {
        return id;
    }


    protected String getRegressionId() {
        return "ZGF0YS1jaGFuZ2UtdjFodHRwczovL215ZW5kcG9pbnQuY29t";
    }

    @Override
    protected void deleteResource() throws Exception {
        deleteDescriptor.run(getId(), testUtils.getOpsAccessToken());
    }

    @Override
    protected void createResource() throws Exception {
        createDescriptor.run(getId(), testUtils.getOpsAccessToken());
    }

    @Override
    protected int expectedOkResponseCode() {
        return 307;
    }


    @Test
    public void should_return404_when_accessingDataThatDoesntExist() throws Exception {
        deleteResource();
        ClientResponse response = descriptor.run(getId(), testUtils.getOpsAccessToken());
        assertEquals(error(response.getEntity(String.class)), 404, response.getStatus());
    }

    @Test
    public void should_return20X_when_retrievingExistingResource_RegressionTest() throws Exception {
        createDescriptor.run(getRegressionId(), testUtils.getOpsAccessToken());
        ClientResponse response = descriptor.run(getRegressionId(), testUtils.getOpsAccessToken());
        assertEquals(error(""), expectedOkResponseCode(), response.getStatus());
        validate20XResponse(response, descriptor);
    }
}